喜宴 (豆瓣)
Description: 喜宴电影简介和剧情介绍,喜宴影评、图片、预告片、影讯、论坛、在线购票
Keywords: 喜宴,囍宴,喜宴影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.154豆瓣电影Top250

# 喜宴 囍宴 (1993)

导演: 李安
编剧: 李安 / 冯光远 / 詹姆斯·夏慕斯
主演: 赵文瑄 / 郎雄 / 归亚蕾 / 金素梅 / 米切尔·利希藤斯坦
类型: 剧情 / 喜剧 / 爱情 / 同性 / 家庭
制片国家/地区: 中国台湾 / 美国
语言: 汉语普通话 / 英语
上映日期: 1993-02(柏林电影节) / 1993-08-04(美国)
片长: 108分钟
又名: The Wedding Banquet
IMDb: tt0107156
豆瓣评分
引用
9.0
337449人评价
5星
55.0%
4星
38.7%
3星
5.9%
2星
0.3%
1星
0.1%
想看 看过
评价:
推荐

## 喜宴的剧情简介 · · · · · ·

伟同（赵文瑄）是事业有成的男同志，与男友赛门（Mitchell Lichtenstein）在美国过着幸福的同居日子，烦恼来自要用各种招数应对远在台北的父（郎雄）母（归亚蕾）的一次次逼婚。伟同被逼以“乖乖仔”形象修书一封声称会在美国结婚，没料父母想亲眼见证。无奈，他只得拉上来自上海的不得志的女艺术家葳葳（金素梅）“假婚”，想逃过一劫。
父母对葳葳相当满意，却对伟同的草率态度不满，为让父母满意尽快返回台北，伟同犹如“拼命三郎”使出了浑身解数。但人算不如天算，不断的波折使得父母的返台日期一次次推迟，令他和赛门的感情亮起“红灯”，而葳葳又意外怀上了他的孩子。似乎，伟同在强大的父母（传统）面前，只能选择去做一个 “表面正常”的男人。 ©豆瓣

## 喜宴的演职员 · · · · · · ( 全部 23 )

- 李安 导演
- 赵文瑄 饰 Wai-Tung Gao
- 郎雄 饰 Mr. Gao
- 归亚蕾 饰 Mrs. Gao
- 金素梅 饰 Wei-Wei
- 米切尔·利希藤斯坦 饰 Simon

## 喜宴的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片697 · 添加 )

## 喜宴的获奖情况 · · · · · · ( 全部 )

- 第66届奥斯卡金像奖
- 最佳外语片(提名)
- 李安

- 第43届柏林国际电影节
- 金熊奖 最佳影片
- 李安

- 第51届金球奖
- 电影类 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  推手

  饮食男女

  春光乍泄

  断背山

  蓝宇

  谁先爱上他的

  燃烧女子的肖像

  每分钟120击

  请以你的名字呼唤我

  莫里斯

我要写短评

## 喜宴的短评 · · · · · · ( 全部 83463 条 )

热门 / 最新 / 好友

### 3153 有用 ryanking1219 看过 2012-11-23 22:07:48

这片在20年前是多么得前卫出格阿！！

### 4637 有用 影志 看过 2005-11-09 04:58:09

“妈，同性恋的人能够在各方面合得来凑合在一起生活，非常不容易。所以我跟赛门都很珍惜对方。” 李安总能在边缘和传统之间找到恰到好处的平衡点，然后双双将我们击溃。

### 1595 有用 小M 看过 2009-12-23 17:06:22

爸爸肯定也是gay的嘛，多明显啊~Simon是多么理想化的同性伴侣啊！金素梅太像叶童了~我喜欢李安这个系列的电影，很回味~还有赵文瑄实在是太帅了！噢，薛绍~

### 1243 有用 Ruby姐姐 看过 2012-11-23 22:09:28

传统的闹洞房太可怕了

### 4406 有用 王神爱 看过 2010-03-20 01:39:12

台湾跟大陆假结婚，其实在跟美国搞同性恋

> 更多短评 83463条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 喜宴的影评 · · · · · · ( 全部 1196 条 )

热门 / 最新 / 好友
贝塔先生 2008-08-10 00:09:55

## 信任，勇敢以及爱

12年前的影评，今天看了真感慨。 这些年，时移世易，有些改变，也有些没变。 影评即使很稚嫩，但遥看12年前那个二了吧唧的小少年， 坐在电脑前认真码字的样子，还真是幸福。 这些年里，在这条影评下方，积累了这么多的评论、观点和故事。 特别想一位一位地邀请回来，听听你们的... (展开)
5275 274 473回应 收起
有为小朋友 2008-04-19 23:40:55

## 温情还是冷酷——妥协之外的批判

这篇影评可能有剧透

《喜宴》，一个热热闹闹的名字，一个皆大欢喜的结局，中间还伴随着一套似乎很和谐很管用的中国式的处世哲学。但是这么一部电影，却看得我从里到外的透心凉。 看起来，这似乎是一组简单、直接而又不可调和的矛盾：儿子是留美白领，父母是传统老人；儿子是gay，父母盼着抱孙子。... (展开)
3087 212 315回应 收起
放飞自我 2006-07-19 13:31:36

## “编剧是电影的核心”——中国导演的编剧能力

不久前看到一篇新闻，英国导演明格拉与陆川、徐静蕾在上海国际电影节上对谈，其中谈到有关编剧的一点深得我心。明格拉和陆川两位导演都是编剧出身，一致认同“编剧是电影的核心”，联想起拉拉杂杂看过的不多的国内电影，就借我喜欢的李安电影《喜宴》的宝地来粗浅谈谈我对国内... (展开)
1975 123 169回应 收起
高梵 2012-10-05 17:14:00

## 伟同的父亲也是同性恋。

这篇影评可能有剧透

伟同的父亲最后和赛门的对话说道“我听，我看，我了解。”而那个片中提到过的张叔叔，正是父亲真正的“爱人”，第一次是他的母亲提到张叔叔，在我们家住了40年是和我们一起把伟同带大的，伟同结婚 张管家也送了一份礼，理由是伟同是张管家看到大的，后面高爸爸又说 把西... (展开)
2117 226 404回应 收起
公子羽 2006-02-19 01:16:17

## 委曲求全

戎马一生的父亲在最后经过机场安检的时候默默举起了双手，那似乎象征着一种投降，一种对生活的委曲求全，以及传统道德之外对另一种生活方式与价值观念的默认。生活本就是这样，永远不可能像墙上静静地挂着的那幅王羲之体白居易诗般，通篇没有一处败笔。就像历经喜宴所缔结的圆... (展开)
789 30 67回应 收起
玫瑰玫瑰我爱你 2020-05-01 19:49:43 #《喜宴》有哪些精彩片段？

## 作为女性，我对女性到底还有多大的恶意？

这篇影评可能有剧透

第一次看《喜宴》是一年多以前，当时有朋友说女主葳葳长得很像我，就好奇找来看，基于此我一直以为我对葳葳是有滤镜的。 最近为了普及中国文化，终于找到了一份带英文字幕的版本，又和英国的朋友重看了一遍。 在葳葳的婚礼上，我的朋友忽然很难过地说Oh, I feel so sorry for h... (展开)
493 5 121回应 收起
· ~~~~~~~~~ 2008-07-07 14:09:08

## 还是喜欢这样蜿蜒曲折的中国故事

赵文瑄的名字和这个人一样样。赵，文，瑄，有点文弱，虚虚腾腾没有主心骨，像个好吃的大白馒头。以前是街坊邻居尤其是大姨大妈们最一致好评的小男孩，用功读书又懂事的，大家羡慕死他妈妈，他妈妈一定也是温柔美丽的。极瘦。 小孩出息了，长大去了美国。三十好几没有结婚，爸... (展开)
200 34 33回应 收起
小张 2014-04-16 11:35:09

## 说说老爸和老张

这篇影评可能有剧透

首先，老爸和老张是一对同志。 有一种电影语言叫契科夫之枪。就是说电影里的每一个人每一个细节都不是凭空而存在的，必然有一定的意义。老张看似无足轻重，完全可以删除这个角色也不会影响剧情。但他没有露面，却在影片里被提起数次，那么老张一定是一个关键人物。 第一个... (展开)
124 2 21回应 收起
nick 2014-01-20 22:34:47

## 父亲三部曲兼谈我眼中的李安

这篇影评可能有剧透

初识李安，是在电影《色戒》。本以为他和吴宇森一样是那种靠拍动作片成名的中国功夫加好莱坞式的混血导演。看了《色戒》，懵懂中惊异于电影的细腻和自始至终的张力。 再识李安，是去年的《Life of Pi》。灯光亮起，梵音相伴，我兀自盯着滚动的字幕，久久沉浸在Pi的故事和回味中... (展开)
172 2 7回应 收起
雪糕 2009-01-08 16:51:11

## 转载两篇《喜宴》影评

林奕华：李安又一次战胜了“时间” http://ent.sina.com.cn 2005年09月19日18:28 南方都市报 　　在李安的电影生涯自传《十年一觉电影梦》(张靓蓓编著)的第103页，有以下一段：“《喜宴》刚在柏林(电影节)上演时，我很紧张，虽然获得满堂彩，但第一个访问我的是香港同性恋团... (展开)
141 5 8回应 收起

> 更多影评 1196篇

添加新讨论

## 讨论区 · · · · · ·

完整有字幕的怎么看呀 | 来自年T人 | 19 回应 | 2022-11-23 10:35:06
在哪可以看啊 | 来自凯凯王 | 22 回应 | 2022-11-21 03:02:55
不喜欢李安的表演 | 来自刺眼 | 29 回应 | 2022-11-20 01:53:10
末尾 老爷子的那一举手 | 来自buer | 57 回应 | 2022-11-20 00:07:48
什么时候发现高父听得懂英文的 | 来自豆友205786977 | 2 回应 | 2022-11-19 23:53:33

> 去这部影片的讨论区（全部244条）

## 关于《喜宴》的问题 · · · · · · ( 全部30个 )

- 电影里总是说老张 老张 老张到底是谁？ 10人回答
- 几段爸爸好像过世的镜头是为何出现，最后一个镜头爸爸双手举起是何用意？ 12人回答

> 全部30个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- He loves a man, she loves a woman(1/2) (影志)
- 电影上的“三部曲”系列~~ (Black Tulip)
- 台湾文艺电影 (L先生)

## 谁在看这部电影 · · · · · ·

- -阿怪
  1分钟前 想看
- 狗蛋吃大包子
  3分钟前 看过
- kkjjdjxx
  5分钟前 看过

451027人看过 / 236945人想看

订阅喜宴的评论:
feed: rss 2.0